@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.115';
+our $VERSION = '0.116';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Jan 24 17:48:57 2019 GMT
+# on Thu Feb  7 17:11:06 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1709,7 +1709,7 @@ __PACKAGE__->status( add => 24907, iridium => '-', 'Iridium 22', 'Tumbling' );
 __PACKAGE__->status( add => 24925, iridium => '-', 'Dummy mass 1', 'Tumbling' );
 __PACKAGE__->status( add => 24926, iridium => '-', 'Dummy mass 2', 'Tumbling' );
 __PACKAGE__->status( add => 24944, iridium => '-', 'Iridium 29', 'Tumbling' );
-__PACKAGE__->status( add => 24945, iridium => '+', 'Iridium 32', '' );
+__PACKAGE__->status( add => 24945, iridium => 'S', 'Iridium 32', '' );
 __PACKAGE__->status( add => 24946, iridium => '-', 'Iridium 33', 'Tumbling' );
 __PACKAGE__->status( add => 24947, iridium => 'D', 'Iridium 27', 'Decayed 2002-02-01' );
 __PACKAGE__->status( add => 24948, iridium => '-', 'Iridium 28', 'Tumbling' );
@@ -1783,8 +1783,8 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 8
-#       Spare [S]: 5
+# Operational [+]: 7
+#       Spare [S]: 6
 #    Tumbling [-]: 32
 #     Decayed [D]: 52
 
